pub enum Chamfer {
Symmetric(f64),
Distances {
face: Shape,
on_face: f64,
on_other: f64,
},
Angle {
face: Shape,
distance: f64,
angle: f64,
},
}Expand description
One edge’s chamfer, in any of the three spellings.
Variants
Symmetric(f64)
The same distance back along both faces, as chamfer_edge.
Distances
on_face along face and on_other along the other face, as
chamfer_edge_distances.
Fields
Angle
distance along face, leaving it at angle radians, as
chamfer_edge_angle.