chamfer_edge_distances

Function chamfer_edge_distances 

pub fn chamfer_edge_distances(
    model: &mut Model,
    solid: &Shape,
    edge: &Shape,
    face: &Shape,
    on_face: f64,
    on_other: f64,
    tol: Tolerances,
) -> OgeomResult<Built>
Bevel a straight edge, cutting on_face back along face and on_other along the edge’s other face.

The asymmetric chamfer: face names which side the first distance applies to, and must be one of the two faces meeting at the edge.

Errors

As chamfer_edge, and additionally if face is not one of the edge’s two faces.